import os
import sys


def cmd():
    args = sys.argv
    if len(args) == 1:
        os.system("curl http://172.17.0.1:8080")
    elif args[-1] == "gpu":
        os.system("curl http://172.17.0.1:8080/gpu")
    elif args[-1] == "top":
        os.system("curl http://172.17.0.1:8080/top")
    elif args[-1] == "topall":
        os.system("curl http://172.17.0.1:8080/top_all")
    elif args[-1] == "query":
        os.system("curl http://172.17.0.1:8080/query")
    else:
        print("Usage: idscheck [(Null)|gpu|top|topall]")



import setuptools
from setuptools.command.install_scripts import install_scripts


# class InstallScripts(install_scripts):

#     def run(self):
#         setuptools.command.install_scripts.install_scripts.run(self)

#         # Rename some script files
#         for script in self.get_outputs():
#             if basename.endswith(".py") or basename.endswith(".sh"):
#                 dest = script[:-3]
#             else:
#                 continue
#             print("moving %s to %s" % (script, dest))
#             shutil.move(script, dest)


with open("README.md", "r",  encoding='UTF-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="idscheck",
    version="0.9.0",
    author="Naibo Wang",
    author_email="naibowang@foxmail.com",
    description="A command line tool for IDS student to check GPU allocation",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/NaiboWang/IDSCheck",
    packages=setuptools.find_packages(),
    install_requires=[],
    entry_points={
        'console_scripts': [
            'cursive = idscheck.idscheck.cmd:ids',
        ],
    },
)
